From 732fc1417ca7f569f1c9c3d6d9647863e833fefc Mon Sep 17 00:00:00 2001
From: WeylonSantana <63019821+WeylonSantana@users.noreply.github.com>
Date: Mon, 14 Aug 2023 14:46:08 -0300
Subject: [PATCH] avoid blocking with shield packets flood (#1838)

---
 Intersect.Client/Entities/Player.cs | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/Intersect.Client/Entities/Player.cs b/Intersect.Client/Entities/Player.cs
index cd66f98204..4d15962461 100644
--- a/Intersect.Client/Entities/Player.cs
+++ b/Intersect.Client/Entities/Player.cs
@@ -1506,8 +1506,8 @@ public bool TryBlock()
             var shieldIndex = Options.ShieldIndex;
             var myShieldIndex = MyEquipment[shieldIndex];
 
-            // Return false if character is attacking or if they don't have a shield equipped.
-            if (IsAttacking || shieldIndex < 0 || myShieldIndex < 0)
+            // Return false if character is attacking, or blocking or if they don't have a shield equipped.
+            if (IsAttacking || IsBlocking || shieldIndex < 0 || myShieldIndex < 0)
             {
                 return false;
             }